@@ -47,6 +47,7 @@ export type Sources = {
     name: string;
     supported_strategies: string[];
     supports_rollback: boolean;
+    changelog_format: "html" | "markdown" | "raw";
   };
 };
 
@@ -60,6 +61,7 @@ export type Addon = {
   download_url: string;
   date_published: string;
   version: string;
+  changelog_url: string;
   folders: { name: string }[];
   options: { strategy: Strategy };
   deps: { id: string }[];
@@ -212,6 +214,13 @@ export class Api {
     });
   }
 
+  async getChangelog(changelogUrl: string): Promise<string> {
+    return await this._request({
+      method: "get_changelog",
+      params: { profile: this.profile, changelog_url: changelogUrl },
+    });
+  }
+
   async reconcile(matcher: ReconciliationStage): Promise<ReconcileResult> {
     return await this._request({
       method: "reconcile",
