@@ -589,6 +589,8 @@ def list_installed(
                     for d in addons
                 )
             )
+            if addons
+            else True
         )
         .order_by(models.Pkg.source, models.Pkg.name)
         .all()
@@ -636,6 +638,18 @@ def reveal(obj: ManagerWrapper, addon: Defn) -> None:
         Report([(addon, E.PkgNotInstalled())]).generate_and_exit()
 
 
+@main.command()
+@click.argument('addon', callback=_with_manager(partial(parse_into_defn, raise_invalid=False)))
+@click.pass_obj
+def view_changelog(obj: ManagerWrapper, addon: Defn) -> None:
+    "View the changelog of an installed add-on."
+    pkg = obj.m.get_pkg(addon, partial_match=True)
+    if pkg:
+        click.echo_via_pager(obj.m.run(obj.m.get_changelog(pkg.changelog_url)))
+    else:
+        Report([(addon, E.PkgNotInstalled())]).generate_and_exit()
+
+
 def _show_active_config(ctx: click.Context, _param: click.Parameter, value: bool) -> None:
     if value:
         click.echo(ctx.obj.m.config.json(indent=2))
