@@ -1,15 +1,14 @@
 from __future__ import annotations
 
 from enum import Enum
-import json
 import os
 from pathlib import Path, PurePath
-from shutil import copytree, ignore_patterns
 from tempfile import gettempdir
 
 import click
 from loguru import logger
-from pydantic import BaseSettings as _BaseConfig, Field, PydanticValueError, validator
+from pydantic import BaseSettings, Field, PydanticValueError, validator
+from pydantic.env_settings import SettingsSourceCallable
 
 from .utils import trash
 
@@ -42,15 +41,20 @@ def _validate_path_is_writable_dir(value: Path) -> Path:
     return value
 
 
-class BaseConfig(_BaseConfig):
+class BaseConfig(BaseSettings):
     class Config:  # type: ignore
         env_prefix = 'INSTAWOW_'
 
-    def _build_values(
-        self, init_kwargs: dict[str, object], *args: object, **kwargs: object
-    ) -> dict[str, object]:
-        # Prioritise env vars
-        return {**init_kwargs, **self._build_environ()}
+        @classmethod
+        def customise_sources(
+            cls,
+            init_settings: SettingsSourceCallable,
+            env_settings: SettingsSourceCallable,
+            *args: SettingsSourceCallable,
+            **kwargs: SettingsSourceCallable,
+        ) -> tuple[SettingsSourceCallable, ...]:
+            # Prioritise env vars
+            return (env_settings, init_settings)
 
 
 class Flavour(str, Enum):
@@ -58,13 +62,13 @@ class Flavour(str, Enum):
     classic = 'classic'
 
 
-class GlobalConfig(BaseConfig):
+class Config(BaseConfig):
     config_dir: Path = Field(default_factory=_get_default_config_dir)
     profile: str = Field(_default_profile, min_length=1, strip_whitespace=True)
     addon_dir: Path
     game_flavour: Flavour
-    auto_update_check: bool = True
     temp_dir: Path = Path(gettempdir(), 'instawow')
+    auto_update_check: bool = True
 
     @validator('config_dir', 'addon_dir', 'temp_dir')
     def _validate_expand_path(cls, value: Path) -> Path:
@@ -77,18 +81,19 @@ class GlobalConfig(BaseConfig):
         return _validate_path_is_writable_dir(value)
 
     @staticmethod
-    def is_classic_folder(folder: os.PathLike[str]) -> bool:
+    def infer_flavour(folder: os.PathLike[str] | str) -> Flavour:
         tail = PurePath(folder).parts[-3:]
-        return tuple(map(str.casefold, tail)) in {
+        is_classic_folder = tuple(map(str.casefold, tail)) in {
             ('_classic_', 'interface', 'addons'),
             ('_classic_ptr_', 'interface', 'addons'),
         }
+        return Flavour.classic if is_classic_folder else Flavour.retail
 
     @classmethod
-    def get_dummy_config(cls, **kwargs: object) -> GlobalConfig:
+    def get_dummy_config(cls, **kwargs: object) -> Config:
         "Create a dummy configuration with default values."
-        template = {'game_flavour': Flavour.retail, 'addon_dir': _novalidate}
-        dummy_config = cls.parse_obj({**template, **kwargs})
+        defaults = {'addon_dir': _novalidate, 'game_flavour': Flavour.retail}
+        dummy_config = cls.parse_obj({**defaults, **kwargs})
         return dummy_config
 
     @classmethod
@@ -99,19 +104,13 @@ class GlobalConfig(BaseConfig):
         return profiles
 
     @classmethod
-    def read(cls, profile: str) -> GlobalConfig:
+    def read(cls, profile: str) -> Config:
         "Read the configuration from disk."
         dummy_config = cls.get_dummy_config(profile=profile)
-        dummy_config.migrate_legacy_dirs()
-        config = cls.parse_raw(dummy_config.config_file.read_text(encoding='utf-8'))
-        if dummy_config.profile != config.profile:
-            raise ValueError(
-                'profile location does not match profile value of '
-                f'"{config.profile}" in {dummy_config.config_file}'
-            )
+        config = cls.parse_file(dummy_config.config_file, encoding='utf-8')
         return config
 
-    def ensure_dirs(self) -> GlobalConfig:
+    def ensure_dirs(self) -> Config:
         "Create the various folders used by instawow."
         for dir_ in (
             self.config_dir,
@@ -124,7 +123,7 @@ class GlobalConfig(BaseConfig):
             dir_.mkdir(exist_ok=True, parents=True)
         return self
 
-    def write(self) -> GlobalConfig:
+    def write(self) -> Config:
         """Write the configuration on disk.
 
         ``write``, unlike ``ensure_dirs``, should only be called when configuring
@@ -137,28 +136,6 @@ class GlobalConfig(BaseConfig):
         self.config_file.write_text(output, encoding='utf-8')
         return self
 
-    def migrate_legacy_dirs(self) -> GlobalConfig:
-        "Migrate a profile-less configuration to the new format."
-        legacy_config_file = self.config_dir / 'config.json'
-        if (
-            self.profile == _default_profile
-            and not self.profile_dir.exists()
-            and legacy_config_file.exists()
-        ):
-            legacy_json = json.loads(legacy_config_file.read_text(encoding='utf-8'))
-            legacy_json.pop('profile', None)
-            legacy_config = self.parse_obj(legacy_json)
-            ignores = ignore_patterns('profiles')
-
-            logger.info('migrating legacy configuration')
-            copytree(self.config_dir, self.profile_dir, ignore=ignores)
-            legacy_config.write()
-            trash(
-                [i for i in self.config_dir.iterdir() if i.name != 'profiles'], dest=self.temp_dir
-            )
-
-        return self
-
     def delete(self) -> None:
         "Delete the configuration files associated with this profile."
         trash((self.profile_dir,), dest=self.temp_dir, missing_ok=True)
@@ -196,10 +173,7 @@ class GlobalConfig(BaseConfig):
         return self.temp_dir / 'cache'
 
 
-Config = GlobalConfig
-
-
-def setup_logging(config: GlobalConfig, log_level: str = 'INFO') -> int:
+def setup_logging(config: Config, log_level: str = 'INFO') -> int:
     import logging
 
     class InterceptHandler(logging.Handler):
