@@ -1,18 +1,19 @@
 from __future__ import annotations
 
+from collections.abc import Iterable
 from contextlib import suppress
 from functools import total_ordering
 import re
-from typing import TYPE_CHECKING, FrozenSet, Iterable, List, Tuple, cast
+from typing import cast
 
+from typing_extensions import TypeAlias
+
+from . import manager
 from .models import PkgFolder
 from .resolvers import CurseResolver, Defn, InstawowResolver, TukuiResolver, WowiResolver
 from .utils import TocReader, bucketise, cached_property, merge_intersecting_sets, uniq
 
-if TYPE_CHECKING:
-    from .manager import Manager
-
-    MatchGroups = List[Tuple[List['AddonFolder'], List[Defn]]]
+MatchGroups: TypeAlias = 'list[tuple[list[AddonFolder], list[Defn]]]'
 
 
 _ids_to_sources = {
@@ -53,19 +54,19 @@ class AddonFolder:
         return self.name < other
 
     @cached_property
-    def defns_from_toc(self) -> FrozenSet[Defn]:
+    def defns_from_toc(self) -> frozenset[Defn]:
         return frozenset(
             Defn(s, i)
-            for s, i in ((s, self.toc_reader[k].value) for k, s in _ids_to_sources.items())
+            for s, i in ((s, self.toc_reader[k]) for k, s in _ids_to_sources.items())
             if i
         )
 
     @cached_property
     def version(self) -> str:
-        return self.toc_reader['Version', 'X-Packaged-Version', 'X-Curse-Packaged-Version'].value
+        return self.toc_reader['Version', 'X-Packaged-Version', 'X-Curse-Packaged-Version'] or ''
 
 
-def get_folders(manager: Manager) -> Iterable[AddonFolder]:
+def get_folders(manager: manager.Manager) -> Iterable[AddonFolder]:
     pkg_folders = {f.name for f in manager.database.query(PkgFolder).all()}
     unreconciled_folders = (
         p
@@ -79,11 +80,13 @@ def get_folders(manager: Manager) -> Iterable[AddonFolder]:
             yield AddonFolder(folder.name, toc_reader)
 
 
-def get_folder_set(manager: Manager) -> FrozenSet[AddonFolder]:
+def get_folder_set(manager: manager.Manager) -> frozenset[AddonFolder]:
     return frozenset(get_folders(manager))
 
 
-async def match_toc_ids(manager: Manager, leftovers: FrozenSet[AddonFolder]) -> MatchGroups:
+async def match_toc_ids(
+    manager: manager.Manager, leftovers: frozenset[AddonFolder]
+) -> MatchGroups:
     "Attempt to match add-ons from TOC-file source ID entries."
 
     def bucket_keyer(value: AddonFolder):
@@ -97,13 +100,15 @@ async def match_toc_ids(manager: Manager, leftovers: FrozenSet[AddonFolder]) ->
     return [(f, sorted(b, key=sort_keyer)) for b, f in bucketise(matches, bucket_keyer).items()]
 
 
-async def match_dir_names(manager: Manager, leftovers: FrozenSet[AddonFolder]) -> MatchGroups:
+async def match_dir_names(
+    manager: manager.Manager, leftovers: frozenset[AddonFolder]
+) -> MatchGroups:
     "Attempt to match folders against the master catalogue."
 
-    def bucket_keyer(value: Tuple[FrozenSet[AddonFolder], Defn]):
+    def bucket_keyer(value: tuple[frozenset[AddonFolder], Defn]):
         return next(f for f in folders if value[0] & f)
 
-    def sort_keyer(value: Tuple[FrozenSet[AddonFolder], Defn]):
+    def sort_keyer(value: tuple[frozenset[AddonFolder], Defn]):
         folders, defn = value
         return (-len(folders), _sources_to_sort_weights[defn.source])
 
@@ -113,7 +118,7 @@ async def match_dir_names(manager: Manager, leftovers: FrozenSet[AddonFolder]) -
         (
             # We can't use an intersection here because it's not guaranteed
             # to give us ``AddonFolder``s
-            frozenset(e for e in leftovers if e in cast('FrozenSet[AddonFolder]', f)),
+            frozenset(e for e in leftovers if e in cast('frozenset[AddonFolder]', f)),
             Defn(i.source, i.id),
         )
         for i in catalogue.__root__
@@ -128,7 +133,9 @@ async def match_dir_names(manager: Manager, leftovers: FrozenSet[AddonFolder]) -
     ]
 
 
-async def match_toc_names(manager: Manager, leftovers: FrozenSet[AddonFolder]) -> MatchGroups:
+async def match_toc_names(
+    manager: manager.Manager, leftovers: frozenset[AddonFolder]
+) -> MatchGroups:
     "Attempt to match add-ons from TOC-file name entries."
 
     def normalise(value: str):
