@@ -30,18 +30,16 @@ class Strategy(str, Enum):
     version = 'version'
 
 
-class _HashableModel(BaseModel):
-    class Config:
-        allow_mutation = False
-
-    def __eq__(self, other: object) -> bool:
-        return self.__dict__ == (other.__dict__ if isinstance(other, self.__class__) else other)
-
-    def __hash__(self) -> int:
-        return hash(tuple(self.__dict__.items()))
+class ChangelogFormat(str, Enum):
+    html = 'html'
+    markdown = 'markdown'
+    raw = 'raw'
 
 
-class Defn(_HashableModel):
+class Defn(
+    BaseModel,
+    frozen=True,
+):
     source: str
     alias: str
     id: typing.Optional[str] = None
@@ -88,7 +86,13 @@ def normalise_names(replace_delim: str = ' '):
 _slugify = normalise_names('-')
 
 
-class _CatalogueEntryDefaultFields(TypedDict):
+def _format_data_changelog(changelog: str = '') -> str:
+    import urllib.parse
+
+    return f'data:,{urllib.parse.quote(changelog)}'
+
+
+class _CatalogueBaseEntry(TypedDict):
     source: str
     id: str
     slug: str
@@ -112,15 +116,13 @@ class CatalogueEntry(BaseModel):
     derived_download_score: float
 
 
-class Catalogue(BaseModel):
+class Catalogue(
+    BaseModel,
+    json_encoders={set: sorted},
+    keep_untouched=(cached_property,),
+):
     __root__: typing.List[CatalogueEntry]
 
-    class Config:
-        json_encoders: dict[type, Any] = {
-            set: sorted,
-        }
-        keep_untouched: tuple[Any, ...] = (cached_property,)
-
     @classmethod
     async def collate(cls, age_cutoff: datetime | None) -> Catalogue:
         async with manager.init_web_client() as web_client:
@@ -150,30 +152,39 @@ class Catalogue(BaseModel):
         return {a.slug: a.id for a in self.__root__ if a.source == 'curse'}
 
 
-class _OrmModel(BaseModel):
-    class Config:
-        allow_mutation = False
-        orm_mode = True
-
-
-class _PkgModel_PkgFolder(_OrmModel):
+class _PkgModel_PkgFolder(
+    BaseModel,
+    orm_mode=True,
+):
     name: str
 
 
-class _PkgModel_PkgOptions(_OrmModel):
+class _PkgModel_PkgOptions(
+    BaseModel,
+    orm_mode=True,
+):
     strategy: Strategy
 
 
-class _PkgModel_PkgDep(_OrmModel):
+class _PkgModel_PkgDep(
+    BaseModel,
+    orm_mode=True,
+):
     id: str
 
 
-class _PkgModel_PkgVersion(_OrmModel):
+class _PkgModel_PkgVersion(
+    BaseModel,
+    orm_mode=True,
+):
     version: str
     install_time: datetime
 
 
-class PkgModel(_OrmModel):
+class PkgModel(
+    BaseModel,
+    orm_mode=True,
+):
     source: str
     id: str
     slug: str
@@ -183,6 +194,7 @@ class PkgModel(_OrmModel):
     download_url: str
     date_published: datetime
     version: str
+    changelog_url: str
     folders: typing.List[_PkgModel_PkgFolder]
     options: _PkgModel_PkgOptions
     deps: typing.List[_PkgModel_PkgDep]
@@ -197,6 +209,7 @@ class Resolver:
     source: ClassVar[str]
     name: ClassVar[str]
     strategies: ClassVar[Set[Strategy]]
+    changelog_format: ClassVar[ChangelogFormat]
 
     def __init__(self, manager: manager.Manager) -> None:
         self.manager = manager
@@ -226,7 +239,7 @@ class Resolver:
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
         "Yield add-ons from source for cataloguing."
         return
         yield
@@ -299,6 +312,7 @@ class CurseResolver(Resolver):
             Strategy.version,
         }
     )
+    changelog_format = ChangelogFormat.html
 
     # Reference: https://twitchappapi.docs.apiary.io/
     addon_api_url = URL('https://addons-ecs.forgesvc.net/api/v2/addon')
@@ -446,9 +460,12 @@ class CurseResolver(Resolver):
                 f'using {defn.strategy} strategy'
             )
 
+        addon_id = str(metadata['id'])
+        file_id = str(file['id'])
+
         return models.Pkg(
             source=self.source,
-            id=str(metadata['id']),
+            id=addon_id,
             slug=metadata['slug'],
             name=metadata['name'],
             description=metadata['summary'],
@@ -456,6 +473,7 @@ class CurseResolver(Resolver):
             download_url=file['downloadUrl'],
             date_published=parse_datetime(file['fileDate']),
             version=file['displayName'],
+            changelog_url=str(self.addon_api_url / addon_id / 'file' / file_id / 'changelog'),
             options=models.PkgOptions(strategy=defn.strategy),
             deps=[
                 models.PkgDep(id=str(d['addonId'])) for d in file['dependencies'] if d['type'] == 3
@@ -465,7 +483,7 @@ class CurseResolver(Resolver):
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
         classic_version_prefix = '1.13'
 
         def excise_flavours(files: list[CurseAddon_File]):
@@ -498,7 +516,7 @@ class CurseResolver(Resolver):
                     for f in item['latestFiles']
                     if not f['exposeAsAlternative']
                 )
-                yield _CatalogueEntryDefaultFields(
+                yield _CatalogueBaseEntry(
                     source=cls.source,
                     id=str(item['id']),
                     slug=item['slug'],
@@ -560,6 +578,7 @@ class WowiResolver(Resolver):
     source = 'wowi'
     name = 'WoWInterface'
     strategies = frozenset({Strategy.default})
+    changelog_format = ChangelogFormat.raw
 
     # Reference: https://api.mmoui.com/v3/globalconfig.json
     # There's also a v4 API corresponding to the as yet unreleased Minion v4,
@@ -648,19 +667,20 @@ class WowiResolver(Resolver):
             download_url=metadata['UIDownload'],
             date_published=parse_datetime(metadata['UIDate']),
             version=metadata['UIVersion'],
+            changelog_url=_format_data_changelog(metadata['UIChangeLog']),
             options=models.PkgOptions(strategy=defn.strategy),
         )
 
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
         async with web_client.get(cls.list_api_url) as response:
             list_api_items: list[WowiListApiItem] = await response.json()
 
         flavours = set(Flavour)
         for list_item in list_api_items:
-            yield _CatalogueEntryDefaultFields(
+            yield _CatalogueBaseEntry(
                 source=cls.source,
                 id=list_item['UID'],
                 name=list_item['UIName'],
@@ -715,6 +735,7 @@ class TukuiResolver(Resolver):
     source = 'tukui'
     name = 'Tukui'
     strategies = frozenset({Strategy.default})
+    changelog_format = ChangelogFormat.html
 
     # There's also a ``/client-api.php`` endpoint which is apparently
     # used by the Tukui client itself to check for updates for the two retail
@@ -795,13 +816,21 @@ class TukuiResolver(Resolver):
                 tzinfo=timezone.utc
             ),
             version=metadata['version'],
+            changelog_url=(
+                # The changelog URL is not versioned - adding fragment to allow caching
+                str(URL(metadata['changelog']).with_fragment(metadata['version']))
+                if metadata['id'] in {-1, -2}
+                # Regular add-ons don't have dedicated changelogs but rather
+                # link to the changelog tab on the add-on page
+                else _format_data_changelog(metadata['changelog'])
+            ),
             options=models.PkgOptions(strategy=defn.strategy),
         )
 
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
         async def fetch_ui(ui_slug: str) -> tuple[set[Flavour], list[TukuiUi]]:
             async with web_client.get(cls.api_url.with_query({'ui': ui_slug})) as response:
                 return ({Flavour.retail}, [await response.json(content_type=None)])  # text/html
@@ -823,7 +852,7 @@ class TukuiResolver(Resolver):
             ]
         ):
             for item in items:
-                yield _CatalogueEntryDefaultFields(
+                yield _CatalogueBaseEntry(
                     source=cls.source,
                     id=str(item['id']),
                     slug='',
@@ -862,12 +891,14 @@ class GithubRelease(TypedDict):
     tag_name: str  # Hopefully the version
     published_at: str  # ISO datetime
     assets: list[GithubRelease_Asset]
+    body: str
 
 
 class GithubResolver(Resolver):
     source = 'github'
     name = 'GitHub'
     strategies = frozenset({Strategy.default, Strategy.latest, Strategy.version})
+    changelog_format = ChangelogFormat.markdown
 
     repos_api_url = URL('https://api.github.com/repos')
 
@@ -965,6 +996,7 @@ class GithubResolver(Resolver):
             download_url=matching_asset['browser_download_url'],
             date_published=parse_datetime(release_metadata['published_at']),
             version=release_metadata['tag_name'],
+            changelog_url=_format_data_changelog(release_metadata['body']),
             options=models.PkgOptions(strategy=defn.strategy),
         )
 
@@ -973,6 +1005,7 @@ class InstawowResolver(Resolver):
     source = 'instawow'
     name = 'instawow'
     strategies = frozenset({Strategy.default})
+    changelog_format = ChangelogFormat.raw
 
     _addons = {
         ('0', 'weakauras-companion'),
@@ -1004,14 +1037,15 @@ class InstawowResolver(Resolver):
             download_url=builder.addon_file.as_uri(),
             date_published=datetime.now(timezone.utc),
             version=(await t(builder.checksum)())[:7],
+            changelog_url=_format_data_changelog('n/a'),
             options=models.PkgOptions(strategy=defn.strategy),
         )
 
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
-        yield _CatalogueEntryDefaultFields(
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
+        yield _CatalogueBaseEntry(
             source=cls.source,
             id='1',
             slug='weakauras-companion-autoupdate',
@@ -1063,6 +1097,7 @@ class TownlongYakResolver(Resolver):
     source = 'townlong-yak'
     name = 'Townlong Yak (via WowUp.Hub)'
     strategies = frozenset({Strategy.default})
+    changelog_format = ChangelogFormat.html
 
     _api_url = 'https://hub.wowup.io/addons/author/foxlit'
 
@@ -1111,19 +1146,20 @@ class TownlongYakResolver(Resolver):
             download_url=file['download_url'],
             date_published=datetime.now(timezone.utc),
             version=file['tag_name'],
+            changelog_url=_format_data_changelog(file['body']),
             options=models.PkgOptions(strategy=defn.strategy),
         )
 
     @classmethod
     async def catalogue(
         cls, web_client: aiohttp.ClientSession
-    ) -> AsyncIterator[_CatalogueEntryDefaultFields]:
+    ) -> AsyncIterator[_CatalogueBaseEntry]:
         async with web_client.get(cls._api_url) as response:
             foxlit_addons: WowUpHubAddons = await response.json()
 
             for addon in foxlit_addons['addons']:
                 slug = URL(addon['repository']).name
-                yield _CatalogueEntryDefaultFields(
+                yield _CatalogueBaseEntry(
                     source=cls.source,
                     id=slug,
                     slug=slug,
