@@ -10,11 +10,6 @@ import pytest
 from instawow import cli, utils
 
 
-@pytest.fixture(autouse=True)
-def mock(mock_all):
-    pass
-
-
 @pytest.fixture
 def feed_pt():
     pipe_input = create_pipe_input()
@@ -26,7 +21,7 @@ def feed_pt():
 @pytest.fixture
 def run(monkeypatch, event_loop, iw_config, iw_web_client):
     def runner(self, awaitable):
-        self.web_client = iw_web_client
+        self.contextualise(web_client=iw_web_client)
         return event_loop.run_until_complete(awaitable)
 
     monkeypatch.setattr('instawow.manager.CliManager.run', runner)
@@ -254,7 +249,7 @@ def test_version_strategy_lifecycle(iw_config, run):
     assert run('remove curse:molinari').output == '✓ curse:molinari\n  removed\n'
     assert (
         run('install --version foo curse:molinari').output
-        == f"✗ curse:molinari\n  no files compatible with {iw_config.game_flavour} using version strategy\n"
+        == f"✗ curse:molinari\n  no files match {iw_config.game_flavour} using version strategy\n"
     )
     assert (
         run('install --version 80000.57-Release curse:molinari').output
